@@ -1,5 +1,5 @@
 package Mojolicious::Plugin::Yancy;
-our $VERSION = '0.019';
+our $VERSION = '0.020';
 # ABSTRACT: Embed a simple admin CMS into your Mojolicious application
 
 #pod =head1 SYNOPSIS
@@ -345,7 +345,7 @@ sub register {
     my ( $self, $app, $config ) = @_;
     my $route = $config->{route} // $app->routes->any( '/yancy' );
     $route->to( return_to => $config->{return_to} // '/' );
-    $config->{controller_class} //= 'Yancy';
+    $config->{api_controller} //= 'Yancy::API';
 
     # Resources and templates
     my $share = path( __FILE__ )->sibling( 'Yancy' )->child( 'resources' );
@@ -431,7 +431,7 @@ sub register {
     $route->get( '/' )->name( 'yancy.index' )
         ->to(
             template => 'yancy/index',
-            controller => $config->{controller_class},
+            controller => $config->{api_controller},
             action => 'index',
         );
 
@@ -484,7 +484,7 @@ sub _build_openapi_spec {
         $paths{ '/' . $name } = {
             get => {
                 'x-mojo-to' => {
-                    controller => $config->{controller_class},
+                    controller => $config->{api_controller},
                     action => 'list_items',
                     collection => $name,
                 },
@@ -535,7 +535,7 @@ sub _build_openapi_spec {
             },
             post => {
                 'x-mojo-to' => {
-                    controller => $config->{controller_class},
+                    controller => $config->{api_controller},
                     action => 'add_item',
                     collection => $name,
                 },
@@ -577,7 +577,7 @@ sub _build_openapi_spec {
 
             get => {
                 'x-mojo-to' => {
-                    controller => $config->{controller_class},
+                    controller => $config->{api_controller},
                     action => 'get_item',
                     collection => $name,
                     id_field => $id_field,
@@ -601,7 +601,7 @@ sub _build_openapi_spec {
 
             put => {
                 'x-mojo-to' => {
-                    controller => $config->{controller_class},
+                    controller => $config->{api_controller},
                     action => 'set_item',
                     collection => $name,
                     id_field => $id_field,
@@ -633,7 +633,7 @@ sub _build_openapi_spec {
 
             delete => {
                 'x-mojo-to' => {
-                    controller => $config->{controller_class},
+                    controller => $config->{api_controller},
                     action => 'delete_item',
                     collection => $name,
                     id_field => $id_field,
@@ -705,7 +705,7 @@ Mojolicious::Plugin::Yancy - Embed a simple admin CMS into your Mojolicious appl
 
 =head1 VERSION
 
-version 0.019
+version 0.020
 
 =head1 SYNOPSIS
 
@@ -1042,7 +1042,7 @@ Doug Bell <preaction@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by Doug Bell.
+This software is copyright (c) 2018 by Doug Bell.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
