@@ -232,6 +232,11 @@ var app = new Vue({
             }
         },
 
+        setCollection: function ( name ) {
+            this.currentCollection = name;
+            $( '#sidebar-collapse' ).collapse('hide');
+        },
+
         fetchSpec: function () {
             var self = this;
             delete self.error.fetchSpec;
@@ -509,6 +514,10 @@ var app = new Vue({
         },
 
         showAddItem: function () {
+            if ( this.addingItem ) {
+                this.cancelAddItem();
+                return;
+            }
             this.toggleRow();
             this.newItem = this.createBlankItem();
             this.addingItem = true;
