@@ -1,5 +1,5 @@
 package Yancy::Plugin::Auth::Basic;
-our $VERSION = '0.019';
+our $VERSION = '0.020';
 # ABSTRACT: A simple auth module for a site
 
 #pod =encoding utf8
@@ -259,10 +259,33 @@ use Digest;
 sub register {
     my ( $self, $app, $config ) = @_;
     # Prepare and validate backend data configuration
-    my $coll = $config->{collection};
+    die "Error configuring Auth::Basic plugin: No password digest type defined\n"
+        unless $config->{password_digest} && $config->{password_digest}{type};
+
+    my $coll = $config->{collection}
+        || die "Error configuring Auth::Basic plugin: No collection defined\n";
+    die sprintf(
+        q{Error configuring Auth::Basic plugin: Collection "%s" not found}."\n",
+        $coll,
+    ) unless $app->yancy->config->{collections}{$coll};
+
     my $username_field = $config->{username_field};
     my $password_field = $config->{password_field} || 'password';
-    my $digest = Digest->new( delete $config->{password_digest}{type}, %{ $config->{password_digest} } );
+
+    my $digest_type = delete $config->{password_digest}{type};
+    my $digest = eval {
+        Digest->new( $digest_type, %{ $config->{password_digest} } )
+    };
+    if ( my $error = $@ ) {
+        if ( $error =~ m{Can't locate Digest/${digest_type}\.pm in \@INC} ) {
+            die sprintf(
+                q{Error configuring Auth::Basic plugin: Password digest type "%s" not found}."\n",
+                $digest_type,
+            );
+        }
+        die "Error configuring Auth::Basic plugin: Error loading Digest module: $@\n";
+    }
+
     $app->yancy->filter->add( 'auth.digest' => sub {
         my ( $name, $value, $field ) = @_;
         return $digest->add( $value )->b64digest;
@@ -381,7 +404,7 @@ Yancy::Plugin::Auth::Basic - A simple auth module for a site
 
 =head1 VERSION
 
-version 0.019
+version 0.020
 
 =head1 DESCRIPTION
 
@@ -637,7 +660,7 @@ Doug Bell <preaction@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by Doug Bell.
+This software is copyright (c) 2018 by Doug Bell.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
@@ -647,7 +670,7 @@ the same terms as the Perl 5 programming language system itself.
 __DATA__
 @@ yancy/auth/login.html.ep
 % layout 'yancy/auth';
-<main id="app" class="container-fluid" style="margin-top: 10px">
+<main id="app" class="container-fluid">
     <div class="row justify-content-md-center">
         <div class="col-md-4">
             <h1>Login</h1>
@@ -676,7 +699,7 @@ __DATA__
 
 @@ yancy/auth/unauthorized.html.ep
 % layout 'yancy/auth';
-<main class="container-fluid" style="margin-top: 10px">
+<main class="container-fluid">
     <div class="row">
         <div class="col">
             <h1>Unauthorized</h1>
